"""Predefined aliases are taken from the RDFa Core Initial Context [1] and supplemented
with ontologies that have been predefined in other namespace libraries.

Generated using src/utils/generate_predefined.py in the pyrdf-prefix repo.

Source: https://www.w3.org/2011/rdfa-context/rdfa-1.1
"""

from ._AS import AS
from ._BRICK import BRICK
from ._CC import CC
from ._CSVW import CSVW
from ._CTAG import CTAG
from ._DC import DC
from ._DC11 import DC11
from ._DCAM import DCAM
from ._DCAT import DCAT
from ._DCMITYPE import DCMITYPE
from ._DCTERMS import DCTERMS
from ._DOAP import DOAP
from ._DQV import DQV
from ._DUV import DUV
from ._FOAF import FOAF
from ._GEO import GEO
from ._GR import GR
from ._GRDDL import GRDDL
from ._ICAL import ICAL
from ._JSONLD import JSONLD
from ._LDP import LDP
from ._MA import MA
from ._OA import OA
from ._ODRL import ODRL
from ._OG import OG
from ._ORG import ORG
from ._OWL import OWL
from ._PROF import PROF
from ._PROV import PROV
from ._QB import QB
from ._RDF import RDF
from ._RDFA import RDFA
from ._RDFS import RDFS
from ._REV import REV
from ._RIF import RIF
from ._RR import RR
from ._SCHEMA import SCHEMA
from ._SD import SD
from ._SH import SH
from ._SIOC import SIOC
from ._SKOS import SKOS
from ._SKOSXL import SKOSXL
from ._SOSA import SOSA
from ._SSN import SSN
from ._TIME import TIME
from ._V import V
from ._VANN import VANN
from ._VCARD import VCARD
from ._VOID import VOID
from ._WDR import WDR
from ._WDRS import DESCRIBEDBY, WDRS
from ._WGS import WGS
from ._XHV import LICENSE, ROLE, XHV
from ._XML import XML
from ._XSD import XSD

__all__ = [
    "AS",
    "BRICK",
    "CC",
    "CSVW",
    "CTAG",
    "DC",
    "DC11",
    "DCAM",
    "DCAT",
    "DCMITYPE",
    "DCTERMS",
    "DESCRIBEDBY",
    "DOAP",
    "DQV",
    "DUV",
    "FOAF",
    "GEO",
    "GR",
    "GRDDL",
    "ICAL",
    "JSONLD",
    "LDP",
    "LICENSE",
    "MA",
    "OA",
    "ODRL",
    "OG",
    "ORG",
    "OWL",
    "PROF",
    "PROV",
    "QB",
    "RDF",
    "RDFA",
    "RDFS",
    "REV",
    "RIF",
    "ROLE",
    "RR",
    "SCHEMA",
    "SD",
    "SH",
    "SIOC",
    "SKOS",
    "SKOSXL",
    "SOSA",
    "SSN",
    "TIME",
    "V",
    "VANN",
    "VCARD",
    "VOID",
    "WDR",
    "WDRS",
    "WGS",
    "XHV",
    "XML",
    "XSD",
]
